@@ -343,8 +343,9 @@ def metric_node(
         "completeness": completeness
     }
 
-    logging.basicConfig(level=logging.DEBUG,
-                        format='%(levelname)s: %(asctime)s: %(message)s')
+    logging.getLogger().setLevel(logging.INFO)
+    # logging.basicConfig(level=logging.DEBUG,
+    #                     format='%(levelname)s: %(asctime)s: %(message)s')
 
     body = event["Records"][0]["body"]
     if isinstance(body, str):
@@ -423,8 +424,9 @@ def summary_node(
 
 
     """
-    logging.basicConfig(level=logging.DEBUG,
-                        format='%(levelname)s: %(asctime)s: %(message)s')
+    logging.getLogger().setLevel(logging.INFO)
+    # logging.basicConfig(level=logging.DEBUG,
+    #                     format='%(levelname)s: %(asctime)s: %(message)s')
     dims_files = [
         "timeliness.csv",
         "accuracy.csv",
